<!DOCTYPE html>
<html lang="en">
<head>
  <meta http-equiv="X-UA-Compatible" content="IE=edge">
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <title>Towalink WireGuard Frontend - Login</title>
  <link rel="stylesheet" media="screen" href="/static/styles.css" />
</head>
<body>
  <div class="loginform">
    <form method="post" action="do_login">
      <div class=loginerror>{{ error_msg }}</div>
      <table>
      <tr>
        <td>
          User:
        </td>
        <td>
          <input class="logininput" type="text" name="username" value="{{ username }}" size="40" />
        </td>
      <tr>
        <td>
          Password:&nbsp;&nbsp;
        </td>
        <td>
          <input class="logininput" type="password" name="password" size="40" />
          <input type="hidden" name="from_page" value="{{ from_page }}" />
        </td>
      </tr>
      <tr>
        <td colspan=2 align=right>
          <input class="button loginmargin" type="submit" value="Login" />
        </td>
      </tr>
      </table>
    </form>
  </div>
</body>
</html>
